CollaborationMode

Struct CollaborationMode 

pub struct CollaborationMode {
    pub mode: ModeKind,
    pub settings: Settings,
}
Collaboration mode for a Codex session.

Fields

mode: ModeKindsettings: Settings

Implementations

Source

impl CollaborationMode

pub fn model(&self) -> &str

pub fn reasoning_effort(&self) -> Option<ReasoningEffort>

pub fn with_updates( &self, model: Option<String>, effort: Option<Option<ReasoningEffort>>, developer_instructions: Option<Option<String>>, ) -> Self

Updates the collaboration mode with new model and/or effort values.

  • model: Some(s) to update the model, None to keep the current model
  • effort: Some(Some(e)) to set effort to e, Some(None) to clear effort, None to keep current effort
  • developer_instructions: Some(Some(s)) to set instructions, Some(None) to clear them, None to keep current

Returns a new CollaborationMode with updated values, preserving the mode.

pub fn apply_mask(&self, mask: &CollaborationModeMask) -> Self

Applies a mask to this collaboration mode, returning a new collaboration mode with the mask values applied. Fields in the mask that are Some will override the corresponding fields, while None values will preserve the original values.

The name field in the mask is ignored as it’s metadata for the mask itself.