Module models

Module models 

Structs

BaseInstructions
Base instructions for the model in a thread. Corresponds to the instructions field in the ResponsesAPI.
DeveloperInstructions
Developer-provided guidance that is injected into a turn as a developer role message.
FileSystemPermissions
FunctionCallOutputPayload
The payload we send back to OpenAI when reporting a tool call result.
LocalShellExecAction
MacOsPermissions
NetworkPermissions
PermissionProfile
ShellCommandToolCallParams
If the name of a ResponseItem::FunctionCall is shell_command, the arguments field should deserialize to this struct.
ShellToolCallParams
If the name of a ResponseItem::FunctionCall is either container.exec or shell, the arguments field should deserialize to this struct.

Enums

ContentItem
FunctionCallOutputBody
FunctionCallOutputContentItem
Responses API compatible content items that can be returned by a tool call. This is a subset of ContentItem with the types we support as function call outputs.
ImageDetail
LocalShellAction
LocalShellStatus
MacOsAutomationValue
MacOsPreferencesValue
MessagePhase
Classifies an assistant message as interim commentary or final answer text.
ReasoningItemContent
ReasoningItemReasoningSummary
ResponseInputItem
ResponseItem
SandboxPermissions
Controls whether a command should use the session sandbox or bypass it.
WebSearchAction

Constants

BASE_INSTRUCTIONS_DEFAULT
VIEW_IMAGE_TOOL_NAME

Functions

format_allow_prefixes
function_call_output_content_items_to_text
Converts structured function-call output content into plain text for human-readable surfaces.
image_close_tag_text
image_open_tag_text
is_image_close_tag_text
is_image_open_tag_text
is_local_image_close_tag_text
is_local_image_open_tag_text
local_image_content_items_with_label_number
local_image_label_text
local_image_open_tag_text