pub struct DeveloperInstructions { /* private fields */ }Expand description
Developer-provided guidance that is injected into a turn as a developer role message.
Implementations
Sourceimpl DeveloperInstructions
impl DeveloperInstructions
pub fn new<T: Into<String>>(text: T) -> Self
pub fn from( approval_policy: AskForApproval, exec_policy: &Policy, request_permission_enabled: bool, ) -> DeveloperInstructions
pub fn into_text(self) -> String
pub fn concat(self, other: impl Into<DeveloperInstructions>) -> Self
pub fn model_switch_message(model_instructions: String) -> Self
pub fn personality_spec_message(spec: String) -> Self
pub fn from_policy( sandbox_policy: &SandboxPolicy, approval_policy: AskForApproval, exec_policy: &Policy, cwd: &Path, request_permission_enabled: bool, ) -> Self
Sourcepub fn from_collaboration_mode(
collaboration_mode: &CollaborationMode,
) -> Option<Self>
pub fn from_collaboration_mode( collaboration_mode: &CollaborationMode, ) -> Option<Self>
Returns developer instructions from a collaboration mode if they exist and are non-empty.