pub enum AskForApproval {
UnlessTrusted,
OnFailure,
OnRequest,
Reject(RejectConfig),
Never,
}Expand description
Determines the conditions under which the user is consulted to approve running the command proposed by Codex.
Variants
UnlessTrusted
Under this policy, only “known safe” commands—as determined by
is_safe_command()—that only read files are auto‑approved.
Everything else will ask the user to approve.
OnFailure
DEPRECATED: All commands are auto‑approved, but they are expected to
run inside a sandbox where network access is disabled and writes are
confined to a specific set of paths. If the command fails, it will be
escalated to the user to approve execution without a sandbox.
Prefer OnRequest for interactive runs or Never for non-interactive
runs.
OnRequest
The model decides when to ask the user for approval.
Reject(RejectConfig)
Fine-grained rejection controls for approval prompts.
When a field is true, prompts of that category are automatically
rejected instead of shown to the user.
Never
Never ask the user to approve commands. Failures are immediately returned to the model, and never escalated to the user for approval.