pub enum ReviewDecision {
Approved,
ApprovedExecpolicyAmendment {
proposed_execpolicy_amendment: ExecPolicyAmendment,
},
ApprovedForSession,
Denied,
Abort,
}Expand description
User’s decision in response to an ExecApprovalRequest.
Variants
Approved
User has approved this command and the agent should execute it.
ApprovedExecpolicyAmendment
User has approved this command and wants to apply the proposed execpolicy amendment so future matching commands are permitted.
Fields
proposed_execpolicy_amendment: ExecPolicyAmendmentApprovedForSession
User has approved this command and wants to automatically approve any
future identical instances (command and cwd match exactly) for the
remainder of the session.
Denied
User has denied this command and the agent should not execute it, but it should continue the session and try something else.
Abort
User has denied this command and the agent should not do anything until the user’s next command.
Implementations
Sourceimpl ReviewDecision
impl ReviewDecision
Sourcepub fn to_opaque_string(&self) -> &'static str
pub fn to_opaque_string(&self) -> &'static str
Returns an opaque version of the decision without PII. We can’t use an ignored flag
on serde because the serialization is required by some surfaces.