pub struct FinalOutput {
pub token_usage: TokenUsage,
}Fields
token_usage: TokenUsageTrait Implementations
Sourceimpl Clone for FinalOutput
impl Clone for FinalOutput
Sourcefn clone(&self) -> FinalOutput
fn clone(&self) -> FinalOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FinalOutput
impl Debug for FinalOutput
Sourceimpl<'de> Deserialize<'de> for FinalOutput
impl<'de> Deserialize<'de> for FinalOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FinalOutput
impl Display for FinalOutput
Sourceimpl From<TokenUsage> for FinalOutput
impl From<TokenUsage> for FinalOutput
Sourcefn from(token_usage: TokenUsage) -> Self
fn from(token_usage: TokenUsage) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for FinalOutput
impl JsonSchema for FinalOutput
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FinalOutput
impl RefUnwindSafe for FinalOutput
impl Send for FinalOutput
impl Sync for FinalOutput
impl Unpin for FinalOutput
impl UnsafeUnpin for FinalOutput
impl UnwindSafe for FinalOutput