pub struct McpServerRefreshConfig {
pub mcp_servers: Value,
pub mcp_oauth_credentials_store_mode: Value,
}Expand description
Config payload for refreshing MCP servers.
Fields
mcp_servers: Valuemcp_oauth_credentials_store_mode: ValueTrait Implementations
Sourceimpl Clone for McpServerRefreshConfig
impl Clone for McpServerRefreshConfig
Sourcefn clone(&self) -> McpServerRefreshConfig
fn clone(&self) -> McpServerRefreshConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpServerRefreshConfig
impl Debug for McpServerRefreshConfig
Sourceimpl<'de> Deserialize<'de> for McpServerRefreshConfig
impl<'de> Deserialize<'de> for McpServerRefreshConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpServerRefreshConfig
impl JsonSchema for McpServerRefreshConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for McpServerRefreshConfig
impl PartialEq for McpServerRefreshConfig
Sourceimpl Serialize for McpServerRefreshConfig
impl Serialize for McpServerRefreshConfig
impl StructuralPartialEq for McpServerRefreshConfig