pub struct RolloutLine {
pub timestamp: String,
pub item: RolloutItem,
}Fields
timestamp: Stringitem: RolloutItemTrait Implementations
Sourceimpl Clone for RolloutLine
impl Clone for RolloutLine
Sourcefn clone(&self) -> RolloutLine
fn clone(&self) -> RolloutLine
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RolloutLine
impl<'de> Deserialize<'de> for RolloutLine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RolloutLine
impl JsonSchema for RolloutLine
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RolloutLine
impl RefUnwindSafe for RolloutLine
impl Send for RolloutLine
impl Sync for RolloutLine
impl Unpin for RolloutLine
impl UnsafeUnpin for RolloutLine
impl UnwindSafe for RolloutLine