pub struct WritableRoot {
pub root: AbsolutePathBuf,
pub read_only_subpaths: Vec<AbsolutePathBuf>,
}Expand description
A writable root path accompanied by a list of subpaths that should remain
read‑only even when the root is writable. This is primarily used to ensure
that folders containing files that could be modified to escalate the
privileges of the agent (e.g. .codex, .git, notably .git/hooks) under
a writable root are not modified by the agent.
Fields
root: AbsolutePathBufread_only_subpaths: Vec<AbsolutePathBuf>By construction, these subpaths are all under root.
Implementations
Sourceimpl WritableRoot
impl WritableRoot
pub fn is_path_writable(&self, path: &Path) -> bool