Structs
- Base
Instructions - Base instructions for the model in a thread. Corresponds to the
instructionsfield in the ResponsesAPI. - Developer
Instructions - Developer-provided guidance that is injected into a turn as a developer role message.
- File
System Permissions - Function
Call Output Payload - The payload we send back to OpenAI when reporting a tool call result.
- Local
Shell Exec Action - MacOs
Permissions - Network
Permissions - Permission
Profile - Shell
Command Tool Call Params - If the
nameof aResponseItem::FunctionCallisshell_command, theargumentsfield should deserialize to this struct. - Shell
Tool Call Params - If the
nameof aResponseItem::FunctionCallis eithercontainer.execorshell, theargumentsfield should deserialize to this struct.
Enums
- Content
Item - Function
Call Output Body - Function
Call Output Content Item - Responses API compatible content items that can be returned by a tool call. This is a subset of ContentItem with the types we support as function call outputs.
- Image
Detail - Local
Shell Action - Local
Shell Status - MacOs
Automation Value - MacOs
Preferences Value - Message
Phase - Classifies an assistant message as interim commentary or final answer text.
- Reasoning
Item Content - Reasoning
Item Reasoning Summary - Response
Input Item - Response
Item - Sandbox
Permissions - Controls whether a command should use the session sandbox or bypass it.
- WebSearch
Action
Constants
Functions
- format_
allow_ prefixes - function_
call_ output_ content_ items_ to_ text - Converts structured function-call output content into plain text for human-readable surfaces.
- image_
close_ tag_ text - image_
open_ tag_ text - is_
image_ close_ tag_ text - is_
image_ open_ tag_ text - is_
local_ image_ close_ tag_ text - is_
local_ image_ open_ tag_ text - local_
image_ content_ items_ with_ label_ number - local_
image_ label_ text - local_
image_ open_ tag_ text